Practice
-----------------------------------------------------

Please answer the following problems to the best of your ability without any outside help. 

You can skip any question that you do not feel qualified to answer or stop working on a question after you worked on it for
about five minutes without solving it.

Problems
==============
.. selectquestion:: fl-get-middle-ps-sq-write
   :fromid: get-middle
   :points: 10

.. selectquestion:: fl-list_loop_two_lists-ps-sq-write
   :fromid: list_loop_two_lists
   :points: 10

.. selectquestion:: fl-has22-ps-sq-write
   :fromid: has22_Write
   :points: 10

.. selectquestion:: fl-sum13-ps-sq-write
   :fromid: sum13_writecode_test_1_v2
   :points: 10

What to do next
============================
.. raw:: html
   
   <h4>Click on the following link to finish a posttest 👉 <b><a href="fl-posttest.html">Posttest</b></h4>
